# Changelog

## 2.9.0 (2025-06-30)

Full Changelog: [v2.8.1...v2.9.0](https://github.com/Papr-ai/papr-pythonSDK/compare/v2.8.1...v2.9.0)

### Features

* **api:** update via SDK Studio ([1fa717e](https://github.com/Papr-ai/papr-pythonSDK/commit/1fa717e48c6305c2c4c49f18722e95a31266c339))

## 2.8.1 (2025-06-30)

Full Changelog: [v2.8.0...v2.8.1](https://github.com/Papr-ai/papr-pythonSDK/compare/v2.8.0...v2.8.1)

### Bug Fixes

* **ci:** correct conditional ([9e3bfd1](https://github.com/Papr-ai/papr-pythonSDK/commit/9e3bfd14dbe6018999a1a22ffff8ac84a673957c))


### Chores

* **ci:** only run for pushes and fork pull requests ([406912e](https://github.com/Papr-ai/papr-pythonSDK/commit/406912eb3d2d92403d66d511771087705e61a163))

## 2.8.0 (2025-06-27)

Full Changelog: [v2.7.0...v2.8.0](https://github.com/Papr-ai/papr-pythonSDK/compare/v2.7.0...v2.8.0)

### Features

* **client:** add support for aiohttp ([e8ea941](https://github.com/Papr-ai/papr-pythonSDK/commit/e8ea941c4f3b3fca4b5d3c8a9355a0ce9c9dd92b))


### Bug Fixes

* **ci:** release-doctor — report correct token name ([cd2d26b](https://github.com/Papr-ai/papr-pythonSDK/commit/cd2d26be6032e09b380ab46efe4bfe67f08b4690))


### Chores

* **tests:** skip some failing tests on the latest python versions ([ff00e9a](https://github.com/Papr-ai/papr-pythonSDK/commit/ff00e9a33cc668c04875a22f7980c82235373e90))

## 2.7.0 (2025-06-19)

Full Changelog: [v2.6.2...v2.7.0](https://github.com/Papr-ai/papr-pythonSDK/compare/v2.6.2...v2.7.0)

### Features

* **api:** update via SDK Studio ([994c0a4](https://github.com/Papr-ai/papr-pythonSDK/commit/994c0a421b63de3288db729bfcbf1cc31e302615))

## 2.6.2 (2025-06-19)

Full Changelog: [v2.6.1...v2.6.2](https://github.com/Papr-ai/papr-pythonSDK/compare/v2.6.1...v2.6.2)

### Documentation

* **client:** fix httpx.Timeout documentation reference ([ca31f17](https://github.com/Papr-ai/papr-pythonSDK/commit/ca31f172bbc9d054a3400f2fc50e4c2639f17a46))

## 2.6.1 (2025-06-18)

Full Changelog: [v2.6.0...v2.6.1](https://github.com/Papr-ai/papr-pythonSDK/compare/v2.6.0...v2.6.1)

### Bug Fixes

* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([6c2abba](https://github.com/Papr-ai/papr-pythonSDK/commit/6c2abbae26a7da899e4c73606197485d50349e3a))


### Chores

* **readme:** update badges ([1dd9392](https://github.com/Papr-ai/papr-pythonSDK/commit/1dd93927116479e91960234c04e7bf72eff32444))

## 2.6.0 (2025-06-17)

Full Changelog: [v2.5.0...v2.6.0](https://github.com/Papr-ai/papr-pythonSDK/compare/v2.5.0...v2.6.0)

### Features

* **api:** update via SDK Studio ([66558c4](https://github.com/Papr-ai/papr-pythonSDK/commit/66558c421ab198628831947858d224280c299ad9))


### Chores

* **ci:** enable for pull requests ([7f7e6c5](https://github.com/Papr-ai/papr-pythonSDK/commit/7f7e6c52ede6a229780741ac401f74a71e26adac))
* **internal:** update conftest.py ([2a36c9b](https://github.com/Papr-ai/papr-pythonSDK/commit/2a36c9b4fc019b48aaf8a2da4d71421fe1f088e2))
* **tests:** add tests for httpx client instantiation & proxies ([1d6ed96](https://github.com/Papr-ai/papr-pythonSDK/commit/1d6ed963119ab35164818c5d2b2af2451fcbe9ac))

## 2.5.0 (2025-06-13)

Full Changelog: [v2.4.0...v2.5.0](https://github.com/Papr-ai/papr-pythonSDK/compare/v2.4.0...v2.5.0)

### Features

* **api:** update via SDK Studio ([fd1bab0](https://github.com/Papr-ai/papr-pythonSDK/commit/fd1bab09d566859a11bd6021121094640bec3814))

## 2.4.0 (2025-06-13)

Full Changelog: [v2.3.0...v2.4.0](https://github.com/Papr-ai/papr-pythonSDK/compare/v2.3.0...v2.4.0)

### Features

* **api:** update via SDK Studio ([ba10eec](https://github.com/Papr-ai/papr-pythonSDK/commit/ba10eec0af063ad741af0587dffb13cf5dde3b03))
* **client:** add follow_redirects request option ([4577c2e](https://github.com/Papr-ai/papr-pythonSDK/commit/4577c2e8287c951b898750a9ced105509aba7932))


### Bug Fixes

* **client:** correctly parse binary response | stream ([0099bdf](https://github.com/Papr-ai/papr-pythonSDK/commit/0099bdf924204499dffe06cbe61b99d1bea0323a))


### Chores

* **ci:** fix installation instructions ([a603af0](https://github.com/Papr-ai/papr-pythonSDK/commit/a603af04ae32f18947e815ebac9b7d0d2d8e9a37))
* **docs:** grammar improvements ([dffdbe6](https://github.com/Papr-ai/papr-pythonSDK/commit/dffdbe6b3113736f9ce175956d2bc1875c97d5bf))
* **docs:** remove reference to rye shell ([581d32b](https://github.com/Papr-ai/papr-pythonSDK/commit/581d32ba64ba96b359edb40cc85842b3eb0c9048))
* **docs:** remove unnecessary param examples ([e37fd8c](https://github.com/Papr-ai/papr-pythonSDK/commit/e37fd8c11691838dcb3aee45865afcde0df5432e))
* **tests:** run tests in parallel ([fad0271](https://github.com/Papr-ai/papr-pythonSDK/commit/fad02716979bf41b5ce16733622d3e77e17b7a26))

## 2.3.0 (2025-05-15)

Full Changelog: [v2.2.0...v2.3.0](https://github.com/Papr-ai/papr-pythonSDK/compare/v2.2.0...v2.3.0)

### Features

* **api:** update via SDK Studio ([37485dc](https://github.com/Papr-ai/papr-pythonSDK/commit/37485dc7c6c11f393bbe51fc01fecba57b1f4263))

## 2.2.0 (2025-05-15)

Full Changelog: [v2.1.0...v2.2.0](https://github.com/Papr-ai/papr-pythonSDK/compare/v2.1.0...v2.2.0)

### Features

* **api:** update via SDK Studio ([22fdd47](https://github.com/Papr-ai/papr-pythonSDK/commit/22fdd4724acf31388c32e9eedf49b648f8e6f3cb))

## 2.1.0 (2025-05-15)

Full Changelog: [v2.0.0...v2.1.0](https://github.com/Papr-ai/papr-pythonSDK/compare/v2.0.0...v2.1.0)

### Features

* **api:** update via SDK Studio ([0097341](https://github.com/Papr-ai/papr-pythonSDK/commit/00973418345ab68f6679ae171d4eb4ef6d227635))


### Chores

* **ci:** upload sdks to package manager ([c4a449a](https://github.com/Papr-ai/papr-pythonSDK/commit/c4a449ac84a69d1b11d9d140b6ae8a2f5bb39385))

## 2.0.0 (2025-05-14)

Full Changelog: [v1.0.1...v2.0.0](https://github.com/Papr-ai/papr-pythonSDK/compare/v1.0.1...v2.0.0)

### Features

* **api:** update via SDK Studio ([9c116ef](https://github.com/Papr-ai/papr-pythonSDK/commit/9c116ef0c678cc8025037fe06ce52e5bbbb84c07))
* **api:** update via SDK Studio ([95f4f78](https://github.com/Papr-ai/papr-pythonSDK/commit/95f4f78d234f96e3be0fa19aa0e1fd53ef3bf5eb))


### Chores

* update SDK settings ([448185c](https://github.com/Papr-ai/papr-pythonSDK/commit/448185cd5236c4dbeca3d016e95594886b12c24f))

## 1.0.1 (2025-05-14)

Full Changelog: [v1.0.0...v1.0.1](https://github.com/Papr-ai/papr-pythonSDK/compare/v1.0.0...v1.0.1)

### Chores

* update SDK settings ([2215a2e](https://github.com/Papr-ai/papr-pythonSDK/commit/2215a2e2cad17a560707314ba43ecdbe4b2aaf68))

## 1.0.0 (2025-05-14)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/Papr-ai/papr-pythonSDK/compare/v0.0.1-alpha.0...v1.0.0)

### Features

* **api:** update via SDK Studio ([7856824](https://github.com/Papr-ai/papr-pythonSDK/commit/78568240285cad273dab70588033260486856539))
* **api:** update via SDK Studio ([b1aaec6](https://github.com/Papr-ai/papr-pythonSDK/commit/b1aaec6d2c0d02d2f9bbb936318a9b420d932ae8))


### Chores

* update SDK settings ([dc4e8e7](https://github.com/Papr-ai/papr-pythonSDK/commit/dc4e8e7c0fe118d94f10b3ecd0b110ba87e53341))
* update SDK settings ([d150fb5](https://github.com/Papr-ai/papr-pythonSDK/commit/d150fb554a92e69c4a33d280155fbf7419fc160a))
